pub struct Null;Expand description
A unit type representing a null value. 表示空值的单元类型
This type is useful for places where a concrete type is required but no actual data needs to be stored. 当需要具体类型但实际上不需要存储数据时,此类型非常有用